/* ESP8266_UDP_recv
 *  
 * UDP üzenetcsomag fogadása és válasz küldése 
 * A program forrása:
 * Manoj R. Thakur: NodeMCU ESP8266 Communication Methods 
 * and Protocols: Programming with Arduino IDE
 * 
 * Tested with Arduino IDE 1.8.13 and ESP8266 Arduino core 2.7.4
 */
#include <ESP8266WiFi.h>  // default from Espressif
#include <WiFiUdp.h>      // default from Espressif 
#include "secrets.h"      // WiFi login secrets

#define UDP_PORT 4210
char packet[256];
char reply[] = "Hi from ESP8266!";

WiFiUDP UDP;

void setup() {
  Serial.begin(115200);
  WiFi.begin(WIFI_SSID, WIFI_PASS);
  Serial.print("Connecting to ");
  Serial.print(WIFI_SSID);
  while (WiFi.status() != WL_CONNECTED) {
    delay(100);
    Serial.print(".");
  }
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
  UDP.begin(UDP_PORT);
  Serial.print("Listening on UDP port ");
  Serial.println(UDP_PORT);
}

void loop() {
  int packetSize = UDP.parsePacket();
  if (packetSize) {       // If packet received...
    Serial.print("Received packet! Size: ");
    Serial.println(packetSize);
    int len = UDP.read(packet, 255);
    if (len > 0) {
      packet[len] = '\0';
    }
    Serial.print(UDP.remoteIP());
    Serial.write(':');
    Serial.println(UDP.remotePort());
    Serial.print("Packet received: ");
    Serial.println(packet);
    // Send return packet
    UDP.beginPacket(UDP.remoteIP(), UDP.remotePort());
    UDP.write(reply);
    UDP.endPacket();
  }
}
